Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1761)

Unified Diff: base/crypto/crypto_module_blocking_password_delegate.h

Issue 6303004: Cleanup: replace usage of "pk11" with "pkcs11" or "crypto module", as appropriate. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: sorting fix again Created 9 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « base/base.gypi ('k') | base/nss_util.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/crypto/crypto_module_blocking_password_delegate.h
diff --git a/base/crypto/pk11_blocking_password_delegate.h b/base/crypto/crypto_module_blocking_password_delegate.h
similarity index 59%
rename from base/crypto/pk11_blocking_password_delegate.h
rename to base/crypto/crypto_module_blocking_password_delegate.h
index c9eb35c113ba711acc3ff92c22bdbcb3243544c8..ae962a828a6476bad6efc855677847013a805721 100644
--- a/base/crypto/pk11_blocking_password_delegate.h
+++ b/base/crypto/crypto_module_blocking_password_delegate.h
@@ -1,9 +1,9 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef BASE_CRYPTO_PK11_BLOCKING_PASSWORD_DELEGATE_H_
-#define BASE_CRYPTO_PK11_BLOCKING_PASSWORD_DELEGATE_H_
+#ifndef BASE_CRYPTO_CRYPTO_MODULE_BLOCKING_PASSWORD_DELEGATE_H_
+#define BASE_CRYPTO_CRYPTO_MODULE_BLOCKING_PASSWORD_DELEGATE_H_
#pragma once
#include <string>
@@ -11,12 +11,12 @@
namespace base {
// PK11_SetPasswordFunc is a global setting. An implementation of
-// PK11BlockingPasswordDelegate should be passed as the user data argument
-// (|wincx|) to relevant NSS functions, which the global password handler will
-// call to do the actual work.
-class PK11BlockingPasswordDelegate {
+// CryptoModuleBlockingPasswordDelegate should be passed as the user data
+// argument (|wincx|) to relevant NSS functions, which the global password
+// handler will call to do the actual work.
+class CryptoModuleBlockingPasswordDelegate {
public:
- virtual ~PK11BlockingPasswordDelegate() {}
+ virtual ~CryptoModuleBlockingPasswordDelegate() {}
// Requests a password to unlock |slot_name|. The interface is
// synchronous because NSS cannot issue an asynchronous
@@ -31,4 +31,4 @@ class PK11BlockingPasswordDelegate {
}
-#endif // BASE_CRYPTO_PK11_BLOCKING_PASSWORD_DELEGATE_H_
+#endif // BASE_CRYPTO_CRYPTO_MODULE_BLOCKING_PASSWORD_DELEGATE_H_
« no previous file with comments | « base/base.gypi ('k') | base/nss_util.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698